@@ -28,6 +28,6 @@ np_proxy_classes = {
     'numpy.flagsobj': {},
 }
 
-monkey_patch('numpy', 'numpy_cloud', SERVER_URL, np_proxy_classes)
-del sys.modules['numpy_cloud']
-__import__('numpy_cloud')
+monkey_patch('numpy', 'cldpy.numpy', SERVER_URL, np_proxy_classes)
+del sys.modules['cldpy.numpy']
+__import__('cldpy.numpy')
